@@ -32,12 +32,12 @@ class S3FineView(View):
     def post(self, request, *args, **kwargs):
         request_dict = request.POST
 
-        if 'filename' not in request_dict or 'mime_type' not in request_dict:
+        if 'file_name' not in request_dict or 'mime_type' not in request_dict:
             return HttpResponseBadRequest(
-                '"filename" or "mime_type" are missing.'
+                '"file_name" or "mime_type" are missing.'
             )
 
-        self.file_name = request_dict['filename']
+        self.file_name = request_dict['file_name']
         self.mime_type = request_dict['mime_type']
 
         return HttpResponse(json.dumps(self.sign()))
